You can cite predictr in your publication or research work using the Digital Object Identifier (DOI):
10.5281/zenodo.4614034

## BibTeX
@software{tvtoglu_2021_4614034,
  author       = {tvtoglu},
  title        = {tvtoglu/predictr: V0.1.18},
  month        = mar,
  year         = 2021,
  publisher    = {Zenodo},
  version      = {V0.1.18},
  doi          = {10.5281/zenodo.4614034},
  url          = {https://doi.org/10.5281/zenodo.4614034}
}


Let me know when you use predictr for your research. I would be happy to list your publication below.
